(define-module (ui update-kernel ajax)
    :use-module (alterator ajax)
    :use-module (alterator woo)
	:use-module (alterator str)
    :export (init))

(define (init-interface)
	(let ((data (woo-read-first "/update-kernel/get_loaded_release")))
		(form-update-value "loaded_release" (woo-get-option data 'loaded_release))
		(form-update-value "loaded_flavour" (woo-get-option data 'loaded_flavour))
		(form-update-value "loaded_version" (woo-get-option data 'loaded_version))
		(get-kernel-image)
		(get-default-kernel)
	)

)

(define (to-update-kernel)
	(form-replace "/update-kernel/update"))

(define (get-kernel-image)
	(let ( (kernelslist (woo-list "/update-kernel/get_installed_kernels")) )
		(form-update-enum "installed-kernels" kernelslist)

		(if (pair? kernelslist)
			(form-update-value "installed-kernels" (woo-get-option (car kernelslist) 'name)))

		(let* ((kernel (form-value "installed-kernels"))
			(modlist (woo-list "/update-kernel/get_installed_modules" 'kernel kernel)))

			(form-update-enum "modlist" modlist)
		)

		(form-update-activity "remove-kernel" (not(null? (cdr kernelslist))))
	)
)

(define (change-kernel-image)
	(let* ((kernel (form-value "installed-kernels"))
		(modlist (woo-list "/update-kernel/get_installed_modules" 'kernel kernel)))
		(form-update-enum "modlist" modlist)
	)
)

(define (set-default-kernel)
	(catch/message
		(lambda()
			(woo-write "/update-kernel/set_default_kernel"
				'kernel (form-value "installed-kernels")
			)
		)
	)

	(get-default-kernel)
)

(define (remove-kernel)
	(let ((name (form-value "installed-kernels")))
		(if (and (not-empty-string? name)
			(form-confirm (string-append (_ "Do you really want to delete kernel ")
										name
										" ?")))
			(catch/message
				(lambda()
					(woo-write "/update-kernel/remove_kernel"
						'kernel (form-value "installed-kernels")
					)
				)
			)
		)
		(let* ((kernelslist (woo-list "/update-kernel/get_installed_kernels")))
			(form-update-enum "installed-kernels" kernelslist)
		)
	)

	(get-kernel-image)
	(get-default-kernel)
)

(define (remove-modules)
	(if (and (not-empty-string? (form-value "modlist"))
			(form-confirm (_ "Do you really want to delete these modules?")))
		(catch/message
			(lambda()
				(woo-write "/update-kernel/remove_modules"
					'modlist (form-value "modlist")
					'kernel (form-value "installed-kernels")
				)
			)
		)
	)
	(change-kernel-image)
)

(define (get-default-kernel)
	(let ((data (woo-read-first "/update-kernel/get_default_kernel")))
		(form-update-value "default-kernel" (woo-get-option data 'default_kernel))
	)
)

(define (init)
	(init-interface)
	(form-bind "update-kernel" "click" to-update-kernel)
	(form-bind "remove-module" "click" remove-modules)
	(form-bind "remove-kernel" "click" remove-kernel)
	(form-bind "default-kernel-btn" "click" set-default-kernel)
	(form-bind "installed-kernels" "change"  change-kernel-image)
)
