(document:surround "/std/frame")

(document:root
	(when loaded
		(let ((data (woo-read-first "/update-kernel/get_loaded_release")))
			(kernel-release-id value (woo-get-option data 'loaded_release))
			(kernel-flavour-id value (woo-get-option data 'loaded_flavour))
			(kernel-version-id value (woo-get-option data 'loaded_version))
			(change-kernel-image)
			(get-default-kernel)
		)))

(define (change-kernel-image)
	(splash-message (_ "Please wait..."))
	(begin-1
		(let ( (kernelslist (woo-list "/update-kernel/get_installed_kernels")) )

			(if (string= (form-value "installed-kernels") "")
				(form-update-value "installed-kernels" (woo-get-option (cond-car kernelslist) 'name)))

			(let* ((kernel (form-value "installed-kernels"))
				(modlist (woo-list "/update-kernel/get_installed_modules" 'kernel kernel)))

				(form-update-enum "modlist" modlist)
			)

			(form-update-activity "remove-kernel" (not(null? (cdr kernelslist))))
		)
	(splash-message))
)

(define (set-default-kernel)
	(woo-catch/message (thunk
		(woo-write "/update-kernel/set_default_kernel"
		'kernel (installed-kernels-id value))
		)
	)
	(get-default-kernel)
)

(define (remove-kernel)
	(splash-message (_ "Please wait..."))
	(begin-1
		(let ((name (form-value "installed-kernels")))
			(if (and (not-empty-string? name)
						(form-confirm (string-append (_ "Do you really want to delete kernel ")
													name
													" ?")))
				(woo-catch/message (thunk
					(woo-write "/update-kernel/remove_kernel"
					'kernel (installed-kernels-id value))
				))
			)
			(let* ((kernelslist (woo-list "/update-kernel/get_installed_kernels")))
				(form-update-enum "installed-kernels" kernelslist)
			)
		)

		(change-kernel-image)
		(get-default-kernel)
	(splash-message))
)

(define (remove-modules)
	(splash-message (_ "Please wait..."))
	(begin-1
		(if (and (not-empty-string? (modlist-id value))
						(form-confirm (_ "Do you really want to delete these modules?")))
			(woo-catch/message (thunk
				(woo-write "/update-kernel/remove_modules"
				'kernel (installed-kernels-id value)
				'modlist (modlist-id value))
				)
			)
		)
		(change-kernel-image)
	(splash-message))
)

(define (change url)
	(frame:replace url)
)

(define (get-default-kernel)
	(let ((data (woo-read-first "/update-kernel/get_default_kernel")))
		(kernel-default-id value (woo-get-option data 'default_kernel))
	)
)

(gridbox columns "5;90;5"
	(spacer)

	(gridbox columns "50;50"

		(vbox
			(gridbox columns "0;100"
				(label text (_ "Loaded kernel release:" ) align "left")
				(document:id kernel-release-id (edit alterability #f))

				(label text (_ "Loaded kernel flavour:" ) align "left")
				(document:id kernel-flavour-id (edit alterability #f))

				(label text (_ "Loaded kernel version:" ) align "left")
				(document:id kernel-version-id (edit alterability #f))
			)
		)

		(vbox
			(gridbox columns "100;0" align "top"
				(label text (_ "Kernel bootable by default:") align "center")
				(spacer)
				(document:id kernel-default-id (label align "center"))
			)
		)

		(vbox
			(separator)

			(gridbox columns "35;65"
				(gridbox columns "0;100"
					(label text (_ "Installed kernels:"))
					(document:id installed-kernels-id (combobox name "installed-kernels"
						enumref "/update-kernel/get_installed_kernels"
						(when changed (change-kernel-image))))
				)
				(spacer)
			)

			(spacer)
			(gridbox columns "0;100"
				(document:id default-kernel-btn-id (button text (_ "Make the kernel bootable by default")
					name "default-kernel-btn" (when clicked (set-default-kernel))))
			)

			(groupbox title (_ "Notes")
				(label text (_ "To make the kernel bootable by default, select the desired version in the list above"))
				(label text (_ "and click the 'Make the kernel bootable by default' button."))
				(label text (_ "Restart the computer to boot with the selected kernel.")))
			(label)
			(label)
			(label)
			(label)
			(label)
			(label)
			(label)
			(label)
			(label)

			(gridbox columns "0;100"
				(document:id remove-btn (button text (_ "Remove kernel") name "remove-kernel"
					(when clicked (remove-kernel))))
				(spacer)
			)

			(separator)
		)

		(vbox
			(document:id modlist-id (checklistbox name "modlist" header (vector (_ "Installed modules"))))
		)

		(document:id upd-kernel-btn (button text (_ "Update kernel...") name "upd-kernel-btn"
			align "left" (when clicked (change "/update-kernel/update"))))

		(document:id apply-btn (button text (_ "Remove module") name "remove-module-btn"
			align "right" (when clicked (remove-modules))))
	)

	(spacer)

	(spacer)
	(groupbox title (_ "Notes")
		(label text (_ "To install modules or update the kernel, click 'Update kernel'"))
		(label text (_ "(You need the latest kernel to install modules)."))
		(label text (_ "This action will require updating the list of packages available in the repository,"))
		(label text (_ "and may take some time (depending on the speed of the Internet connection)."))
	)
	(spacer)
)
