(define-module (ui update-kernel update ajax)
    :use-module (alterator ajax)
    :use-module (alterator woo)
	:use-module (alterator str)
    :export (init))

(define (init-interface)
	(catch/message
		(lambda()
			(woo-write "/update-kernel/apt_get_update")
		)
	)
	(get-flavours)
	(change-flavour)
)

(define (get-flavours)
	(let ( (flavour_list (woo-list "/update-kernel/get_flavours")))
		(form-update-enum "flavours" flavour_list)
		(if (pair? flavour_list)
			(form-update-value "flavours" (woo-get-option (car flavour_list) 'name)))
	)
)

(define (change-flavour)
	(let ((data (woo-read-first "/update-kernel/get_available_kernel" 'flavour (form-value "flavours"))))
		(form-update-value "available-kernel" (woo-get-option data 'available_kernel))
		(form-update-activity "update-kernel-btn" (woo-get-option data 'kernel_installation_possible #f))
		(form-update-activity "install-modules-btn" (woo-get-option data 'modules_installation_possible #f))

		(if (and (not (woo-get-option data 'kernel_installation_possible))
			(woo-get-option data 'modules_installation_possible))

			(form-update-value "message" (_ "Latest kernel is already installed on your system."))
			(form-update-value "message" "")
		)
	)

	(get-apt-modules)
)

(define (get-apt-modules)
	(let* ((flavour (form-value "flavours"))
		(modules_list (woo-list "/update-kernel/get_available_modules" 'flavour flavour)))
		(form-update-enum "available_modlist" modules_list)
	)
	(get-apt-inst-modules)
)

(define (get-apt-inst-modules)
	(if (and (not (string= (form-value "flavours") ""))
			(not (string= (form-value "available-kernel") "")))
		(let ((data (woo-read-first "/update-kernel/get_installed_modules_available_in_apt_cache"
			'flavour (form-value "flavours"))))

			(form-update-value "available_modlist" (woo-get-option data 'inst_avail_mod_list))
		)
	)
)

(define (update-kernel)
	(if (and (not-empty-string? (form-value "available-kernel"))
					(form-confirm (_ "Do you really want to update kernel?")))
		(catch/message
			(lambda()
				(woo-write "/update-kernel/update_kernel"
					'flavour (form-value "flavours")
					'modlist (form-value "available_modlist")
				)
				(form-update-activity "update-kernel-btn" #f)
				(form-update-activity "install-modules-btn" #t)
			)
		)
	)
)

(define (install-modules)
	(if (and (not-empty-string? (form-value "available_modlist"))
			(form-confirm (_ "Do you really want to install modules?")))
		(catch/message
			(lambda()
				(woo-write "/update-kernel/install_modules"
					'flavour (form-value "flavours")
					'modlist (form-value "available_modlist")
				)
			)
		)
	)
)

(define (back)
	(form-replace "/update-kernel"))

(define (init)
	(init-interface)
	(form-bind "back-btn" "click" back)
	(form-bind "install-modules-btn" "click" install-modules)
	(form-bind "update-kernel-btn" "click" update-kernel)
	(form-bind "flavours" "change"  change-flavour)
)
